@@ -9,9 +9,5 @@ def sketch(image):
 
   inverted_blurred = 255 - blurred
   pencil_sketch = cv2.divide(gray_image, inverted_blurred, scale=256.0)
-  cv2.imshow("Sketch", pencil_sketch)
-
-  cv2.imshow("pencil sketch", pencil_sketch)
   cv2.imwrite("sketch.png",pencil_sketch)
-  cv2.waitKey(0)
 
